#!/usr/bin/env python3
"""
#exonware/xwschema/src/exonware/xwschema/facades/__init__.py
XWSchema Facades Module
This module contains facades for BaaS platform integration.
Company: eXonware.com
Author: eXonware Backend Team
Email: connect@exonware.com
Version: 0.4.0.6
Generation Date: 26-Jan-2026
NOTE: This is an OPTIONAL module for BaaS platform integration.
"""

from .baas import XWSchemaBaaSFacade
__all__ = ['XWSchemaBaaSFacade']
